@@ -59,20 +59,23 @@ class UserSpace:
 
         if isinstance(names, list):
             for obj_name in names:
-                obj_type = type(user_space[obj_name])
-                if isinstance(user_space[obj_name], self.tracking_df_types):
-                    # if obj_type in self.tracking_df_types:
+                obj_type = self.fullname(type(user_space[obj_name]))
+                # log.info(
+                #     "Object name: {} - Object type: {} - Tracking: {}".format(obj_name, obj_type, self.tracking_df_types))
+                if obj_type in self.tracking_df_types:
                     df_list.append(
-                        (obj_name, id(user_space[obj_name]), self.fullname(obj_type)))
-
+                        (obj_name, id(user_space[obj_name]), obj_type))                            
+        log.info(
+            "df_list: {}".format(df_list))
         return df_list
 
     @staticmethod
     def load_class(name):
         components = name.split('.')
         mod = importlib.import_module(components[0])
-        for comp in components[1:]:
-            mod = getattr(mod, comp)
+        if len(components) > 1:
+            for comp in components[1:]:
+                mod = getattr(mod, comp)
         return mod
 
     def get_active_models_info(self) -> ModelInfoDict:
@@ -90,6 +93,8 @@ class UserSpace:
                 obj_type = type(user_space[obj_name])
                 for model_type_name in self.tracking_model_types:
                     model_type = self.load_class(model_type_name)
+                    log.info('Model types {} {}'.format(
+                        model_type_name, model_type))
                     if isinstance(user_space[obj_name], model_type):
                         model_dict[obj_name] = {'name': obj_name, 'id': id(
                             user_space[obj_name]), 'obj_class': self.fullname(obj_type), 'base_class': self.fullname(model_type)}
